﻿using Infragistics.Olap.FlatData;
using System;
using System.Collections.Generic;
using System.Linq.Expressions;
using System.Windows;

namespace XamPivotGrid
{
    /// <summary>
    /// MainWindow.xaml の相互作用ロジック
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();

            // サンプルデータを設定
            SettingDatas<SampleData>(SampleData.CreateTestData());
        }

        private void SettingDatas<T>(IEnumerable<T> datas)
        {
            // Pivotに対するデータソースを設定
            FlatDataSource flatData = new FlatDataSource()
            {
                ItemsSource = datas,
                ConnectionSettings = new FlatDataConnectionSettings(){ ItemsSource = datas}
            };


            CubeMetadata cubeMetadata = new CubeMetadata { DataTypeFullName = "XamPivotGrid.SampleData", DisplayName = "コストデータ" };

            // Date Hierarchy
            HierarchyDescriptor dateTimeDescriptor = new HierarchyDescriptor { AppliesToPropertiesOfType = typeof(DateTime) };

            dateTimeDescriptor.AddLevel<DateTime>(dt => "All", "All");
            dateTimeDescriptor.AddLevel<DateTime>(dt => dt.Year, "Years");
            dateTimeDescriptor.AddLevel<DateTime>(dt => dt.SemesterShort(), "Semesters");
            dateTimeDescriptor.AddLevel<DateTime>(dt => dt.QuarterShort(), "Quarters");
            dateTimeDescriptor.AddLevel<DateTime>(dt => dt.MonthShort(), "Months");

            // 時間まで表示するため、DateTime(dt)を丸ごと取得
            dateTimeDescriptor.AddLevel<DateTime>(dt => dt, "Dates");

            flatData.HierarchyDescriptors.Add(dateTimeDescriptor);

            // フォーマット設定
            cubeMetadata.DimensionSettings.Add(new DimensionMetadata()
            {
                SourcePropertyName = "Date",
                DisplayName = "発生日付",
                DimensionType = DimensionType.Dimension,
                AutoGenerateField = true,
                DisplayFormat = "yyyy/MM/dd hh:mm:ss",

            });


            flatData.CubesSettings.Add(cubeMetadata);


            xamPivot.DataSource = flatData;
            xamPivotDataSelector.DataSource = flatData;
        }

    }
}
